@@ -15,39 +15,7 @@ int	ptsin[128];
 int	intout[128];
 int	ptsout[128];
 
-
-# ifdef RT
-# include "vdigsl.c"
-# define TIME 1
-# endif
-
-# ifdef PC
-# include "vdimss.c"
-# define TIME 1
-# endif
-
-# ifdef ATARI
-# include "vditos.c"
-# define TIME 1
-# endif
-
-# ifdef SUN
-# include "vdix11.c"
-# endif
-
-# ifdef NCR
-# include "vdincr.c"
-# endif
-
-# ifdef UVAX
-# include "vdix11.c
-# define TIME 0
-# endif
-
-# ifdef SM9 
-# include "vdiwyse.c"
-# define TIME 1
-# endif
+#include "vdix11.c"
 
 /* calcule les deux coordonnees extremes d'un rectangle rentrant dans la fenetre a partir de x, y, dx, dy */
 /* resultat dans le tableau pxy */
@@ -1056,8 +1024,9 @@ char	*file;
 {
 	FILE * fp;
 	cnat y, flag;
-	char	str[80];
+	char	str[80], mes[TAILLE_CHAINE];
 
+	mes[0] = '\0';
 	y = graph.dy - 2 * HTEXT;
 	flag = 1;
 	if ((fp = fopen(file, LTE)) == 0) 
@@ -1069,7 +1038,7 @@ char	*file;
 		if (y < 0) {
 			y = graph.dy - 2 * HTEXT;
 			flag = 1;
-			if (m_more("")) {
+			if (m_more(mes)) {
 				flag = 0; 
 				break;
 			}
@@ -1080,7 +1049,7 @@ char	*file;
 		y -= HTEXT; 		
 	}
 	if (flag)
-		m_more("");
+		m_more(mes);
 	vdi_clrwk(graph.handle);
 	daffiche(LNDES(fbuf1), 0);
 	informe();
