@@ -460,13 +460,13 @@ vdi_opnwq()
 /***************************************************************************/
 
 
-vdisl_color(handle,index)
-int handle,index;
+void vdisl_color(h, i)
+int h, i;
 {
-if(VFCOL!=index)
+if(VFCOL!=i)
 	{
-	XSetForeground(mdisplay,mcontext,VFCOL=colors[index]);
-	VFCOL=index;
+	XSetForeground(mdisplay,mcontext,VFCOL=colors[i]);
+	VFCOL=i;
 	}
 }
 
