@@ -43,7 +43,7 @@ extern    short syntax;
 void yyerror(s)
   char *s;
 {
- printf ("\nErreur Langage ligne %d : %s\n",yylineno,s);
+ printf ("\nErreur Langage ligne : %s\n",s);
  exit(1);
 }
 /*--------------------------------------------------------------*/
