@@ -42,7 +42,7 @@
     chain_list *ScanGate;
     phfig_list *FigureMbk;
 
-    FigureMbk = addphfig( "core_cx" );
+    FigureMbk = addphfig( "core_cx" ); 
 
     RectangleRdsMbk( FigureMbk, NULL, Contact );
 
@@ -78,6 +78,7 @@
     rds_rec    *Rectangle;
     rds_rec    *ScanGate;
     rds_rec    *Diffusion;
+    rds_rec    *FirstDiff;
 
     chain_list *ScanFence;
     chain_list *ScanIndex;
@@ -124,10 +125,10 @@
             if ( ( ScanGate->mbk_type == MBK_SEGMENT ) && 
                  ( IsExtractNone( ScanGate->flags )  ) )
             {
-              if ( ( ScanGate->x                <= X2 ) &&
-                   ( ScanGate->y                <= Y2 ) &&
-                   ( ScanGate->x + ScanGate->dx >= X1 ) &&
-                   ( ScanGate->y + ScanGate->dy >= Y1 ) )
+              if ( ( ScanGate->x                    <= X2 ) &&
+                   ( ScanGate->y                    <= Y2 ) &&
+                   ( ( ScanGate->x + ScanGate->dx ) >= X1 ) &&
+                   ( ( ScanGate->y + ScanGate->dy ) >= Y1 ) )
               {
                 SetExtractTag( ScanGate->flags );
 
@@ -179,15 +180,15 @@
 
           freechain( HeadGate );
 
-          Diffusion = Rectangle->u_rec.link;
+          FirstDiff = Rectangle->u_rec.link;
 
-          X1 = Diffusion->x;
-          Y1 = Diffusion->y;
+          X1 = FirstDiff->x;
+          Y1 = FirstDiff->y;
 
-          Diffusion->x  += CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 0 ];
-          Diffusion->y  += CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 1 ];
-          Diffusion->dx  = CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 2 ];
-          Diffusion->dy  = CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 3 ];
+          FirstDiff->x  += CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 0 ];
+          FirstDiff->y  += CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 1 ];
+          FirstDiff->dx  = CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 2 ];
+          FirstDiff->dy  = CUT_TRANSISTOR_ELBOW[ Flag ] [ 0 ] [ 3 ];
 
           for ( Index = 1;
                 Index < 4;
@@ -202,11 +203,11 @@
                                             Y1 + CUT_TRANSISTOR_ELBOW[ Flag ] [ Index ] [ 1 ],
                                             CUT_TRANSISTOR_ELBOW[ Flag ] [ Index ] [ 2 ],
                                             CUT_TRANSISTOR_ELBOW[ Flag ] [ Index ] [ 3 ],
-                                            Diffusion->layer,
-                                            MBK_UNKNOWN, RDS_NONE, NULL 
+                                            FirstDiff->layer,
+                                            MBK_VIA, RDS_NONE, NULL 
                                           );
 
-            for ( ScanFence  = (chain_list *)(Rectangle->user);
+            for ( ScanFence  = (chain_list *)(FirstDiff->user);
                   ScanFence != (chain_list *)NULL;
                   ScanFence  = ScanFence->NEXT )
             {
@@ -299,11 +300,11 @@
                 {
                   ScanRectangle = (rds_rec *)( ScanIndex->DATA );
 
-                  if (( IsExtractNone( ScanRectangle->flags )      ) &&
-                      ( ScanRectangle->x                     <= X2 ) &&
-                      ( ScanRectangle->y                     <= Y2 ) &&
-                      ( ScanRectangle->x + ScanRectangle->dx >= X1 ) &&
-                      ( ScanRectangle->y + ScanRectangle->dy >= Y1 ))
+                  if (( IsExtractNone( ScanRectangle->flags )          ) &&
+                      ( ScanRectangle->x                         <= X2 ) &&
+                      ( ScanRectangle->y                         <= Y2 ) &&
+                      ( ( ScanRectangle->x + ScanRectangle->dx ) >= X1 ) &&
+                      ( ( ScanRectangle->y + ScanRectangle->dy ) >= Y1 ) )
                   {
                     SetExtractTag( ScanRectangle->flags );
                    *Previous = ScanRectangle;
@@ -339,11 +340,11 @@
                   {
                     ScanRectangle = (rds_rec *)( ScanIndex->DATA );
 
-                    if (( IsExtractNone( ScanRectangle->flags )      ) &&
-                        ( ScanRectangle->x                     <= X2 ) &&
-                        ( ScanRectangle->y                     <= Y2 ) &&
-                        ( ScanRectangle->x + ScanRectangle->dx >= X1 ) &&
-                        ( ScanRectangle->y + ScanRectangle->dy >= Y1 ))
+                    if (( IsExtractNone( ScanRectangle->flags )          ) &&
+                        ( ScanRectangle->x                         <= X2 ) &&
+                        ( ScanRectangle->y                         <= Y2 ) &&
+                        ( ( ScanRectangle->x + ScanRectangle->dx ) >= X1 ) &&
+                        ( ( ScanRectangle->y + ScanRectangle->dy ) >= Y1 ) )
                     {
                       SetExtractTag( ScanRectangle->flags );
                      *Previous = ScanRectangle;
@@ -503,7 +504,7 @@
      {
        Rectangle->user = (void *)HeadFirstEqui;
 
-       if ( IsExtractEnd( Rectangle->flags ))
+       if ( IsExtractEnd( Rectangle->flags ) )
        {
          HeadFirstEqui = addchain
          (
@@ -521,6 +522,8 @@
              Layer < MAX_FENCE_LAYER;
              Layer++ )
        {
+         if ( ! FenceLayerEnable[ Layer ] ) continue;
+
          for ( Rectangle  = Instance->layertab[ Layer ];
                Rectangle != (rds_rec *)NULL;
                Rectangle  = Rectangle->next )
@@ -547,6 +550,8 @@
                  ScanLayer < MAX_FENCE_LAYER;
                  ScanLayer++ )
            {
+             if ( ! FenceLayerEnable[ ScanLayer ] ) continue;
+
              for ( ScanRectangle  = Instance->layertab[ ScanLayer ];
                    ScanRectangle != (rds_rec *)NULL;
                    ScanRectangle  = ScanRectangle->next )
@@ -556,13 +561,14 @@
                     ( ScanRectangle->u_rec.name == Rectangle->u_rec.name ))
                {
                  Counter++;
-                 ComputeFusionEqui( Rectangle, ScanRectangle );
+                 ComputeFusionEqui( ScanRectangle, Rectangle );
                }
              }
            } 
          }
        }
      }
+
      freechain( HeadFirstEqui );
      return( Counter );
    }
