@@ -739,6 +739,8 @@
              Layer < MAX_FENCE_LAYER;
              Layer++ )
        {
+         if ( ! FenceLayerEnable[ Layer ] ) continue;
+
          for ( Rectangle  = PhysicalInstance->layertab[ Layer ];
                Rectangle != (rds_rec *)NULL;
                Rectangle  = Rectangle->next )
@@ -848,8 +850,8 @@
           Length,
           ( Source->dx << 1) + ( Source->dy << 1),
           ( Drain->dx  << 1) + ( Drain->dy  << 1),
-          (( Source->dx * Source->dy ) / Width ) * SCALE_X,
-          (( Drain->dx  * Drain->dy  ) / Width ) * SCALE_X,
+          (( Source->dx * Source->dy ) / Width ),
+          (( Drain->dx  * Drain->dy  ) / Width ),
           (losig_list *)Grid->user,
           (losig_list *)Source->user,
           (losig_list *)Drain->user
