@@ -895,12 +895,12 @@
                                case RDS_SEG_SOURCE : Transistor = RectangleRds->u_rec.link;
                              }
 
-                             X = Transistor->x;
-                             Y = Transistor->y;
+                             X  = Transistor->x;
+                             Y  = Transistor->y;
                              Dx = Transistor->dx;
                              Dy = Transistor->dy;
 
-                             LayerMbk = ( Transistor->u_rec.link->layer == RDS_NDIF ) ? NTRANS:PTRANS;
+                             LayerMbk = POLY;
                              LayerRds = RDS_GATE;
                            }
 
@@ -952,8 +952,15 @@
                                     );
                           }
                           else
+                          if ( RectangleRds->u_rec.link != (rds_rec *)NULL )
                           if ( RectangleRds->u_rec.link->layer  == RDS_GATE )
                           { 
+                            RectangleRds  = RectangleRds->u_rec.link;
+                            X  = RectangleRds->x;
+                            Y  = RectangleRds->y;
+                            Dx = RectangleRds->dx;
+                            Dy = RectangleRds->dy;
+   
                             addphvia( FigureMbk, 
                                       ( LayerRds == RDS_NDIF ) 
                                       ? ( C_X_N ) : ( C_X_P ),
