@@ -392,7 +392,7 @@ char *name;
 {
 lofig_list *ptfig;
 lofig_list *ptsav;
-loins_list *ptins;
+loins_list *ptins, *tmp_ptr;
 locon_list *ptcon;
 locon_list *ptcon_sav;
 ptype_list *pt;
@@ -409,8 +409,17 @@ ptype_list *pt;
 		HEAD_LOFIG = ptfig->NEXT;
 	else 
 		ptsav->NEXT = ptfig->NEXT;
+/*
 	for (ptins = ptfig->LOINS; ptins; ptins = ptins->NEXT)
 		(void)delloins(ptfig, ptins->INSNAME);
+*/
+	ptins = ptfig->LOINS;
+	while (ptins != NULL) {
+		tmp_ptr = ptins->NEXT;
+		(void) delloins(ptfig, ptins->INSNAME);
+		ptins = tmp_ptr;
+	}
+
 	for (pt = ptfig->BKSIG; pt; pt = pt->NEXT)
 		mbkfree((void *)pt->DATA);
 	for (ptcon = ptfig->LOCON; ptcon; ptcon = ptcon_sav) {
@@ -523,7 +532,7 @@ char *insname;
 {
 loins_list *ptins;
 loins_list *ptsave;
-locon_list *ptcon;
+locon_list *ptcon, *tmp_ptr;
 chain_list *ptchain;
 chain_list *pttmpchain;
 char *figname;
@@ -543,9 +552,16 @@ char *figname;
 		figname = ptins->FIGNAME;
 		ptsave->NEXT = ptins->NEXT;
 	}
+/*
 	for (ptcon = ptins->LOCON; ptcon; ptcon = ptcon->NEXT)
 		mbkfree((void *)ptcon);
-
+*/
+	ptcon = ptins->LOCON;
+	while (ptcon != NULL) {
+		tmp_ptr = ptcon->NEXT;
+		mbkfree((void *) ptcon);
+		ptcon = tmp_ptr;
+	}
 	mbkfree((void *)ptins);
 
 	for (ptins = ptfig->LOINS; ptins; ptins = ptins->NEXT)
@@ -657,7 +673,7 @@ locon_list  *ptcon;
 	(void)fprintf(stderr, "getlocon impossible :\n");
 	(void)fprintf(stderr, "connector %s doesn't exist in figure %s\n", 
   						name, ptfig->NAME);
-	EXIT();
+	EXIT(1);
 }
 
 /*******************************************************************************
@@ -687,7 +703,7 @@ short high;
 	(void)fprintf(stderr, "getlosig impossible :\n");
 	(void)fprintf(stderr, "signal %ld doesn't exist in figure %s\n", 
   						index, ptfig->NAME);
-	EXIT();
+	EXIT(1);
 }
 
 /*******************************************************************************
