@@ -600,7 +600,7 @@ static char **table;
 
 	if (!size)
 		loadcatalog(&table, &size, 'F');
-	return (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp);
+	return size ? (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp) : 0;
 }
 
 /*******************************************************************************
@@ -615,7 +615,7 @@ static char **table;
 
 	if (!size)
 		loadcatalog(&table, &size, 'G');
-	return (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp);
+	return size ? (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp) : 0;
 }
 
 /*******************************************************************************
@@ -630,7 +630,7 @@ static char **table;
 
 	if (!size)
 		loadcatalog(&table, &size, 'C');
-	return (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp);
+	return size ? (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp) : 0;
 }
 
 /*******************************************************************************
@@ -645,7 +645,7 @@ static char **table;
 
 	if (!size)
 		loadcatalog(&table, &size, 'D');
-	return (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp);
+	return size ? (int)bsearch(&figname, table, size, sizeof(char *), pstrcmp) : 0;
 }
 
 /*******************************************************************************
@@ -740,12 +740,13 @@ static int read;
 			(void)fclose((FILE *)((chain_list *)pt)->DATA);
 		}
 		for (nb = 0; nb < 4; nb++) {
-			tabs[nb] = (char **)mbkalloc(sizes[nb] * sizeof(char *));
-			for (i = 0, pt = (void *)cells[nb]; pt;
-					pt = (void *)((chain_list *)pt)->NEXT, i++)
-				tabs[nb][i] = (char *)((chain_list *)pt)->DATA;
-			qsort(tabs[nb], sizes[nb], sizeof(char *), pstrcmp);
-			freechain(cells[nb]);
+			if (sizes[nb] > 0) {
+				tabs[nb] = (char **)mbkalloc(sizes[nb] * sizeof(char *));
+				for (i = 0, pt = (void *)cells[nb]; pt; pt = (void *)((chain_list *)pt)->NEXT, i++)
+					tabs[nb][i] = (char *)((chain_list *)pt)->DATA;
+				qsort(tabs[nb], sizes[nb], sizeof(char *), pstrcmp);
+				freechain(cells[nb]);
+			}
 		}
 	}
 
@@ -845,7 +846,7 @@ int i;
 		fflush(stdout);
 		(void)fprintf(stderr, "*** mbk error ***\n");
 		(void)fprintf(stderr, "addht impossible : hash table size is '0'\n");
-		EXIT();
+		EXIT(1);
 	}
 	pTable = (ht *)mbkalloc(sizeof(struct htable));
 	pTable->length = len;
@@ -916,7 +917,7 @@ int co = 0;
 		fflush(stdout);
 		(void)fprintf(stderr, "*** mbk error ***\n");
 		(void)fprintf(stderr, "addhtitem impossible : value is EMPTYHT or DELETEHT\n");
-		EXIT();
+		EXIT(1);
 	}
 	if (pTable->count++ > (pTable->length) * 8 / 10) {
 		reallocht(pTable);
@@ -960,7 +961,7 @@ int co = 0;
 		fflush(stdout);
 		(void)fprintf(stderr, "*** mbk error ***\n");
 		(void)fprintf(stderr, "sethtitem impossible : value is EMPTYHT or DELETEHT\n");
-		EXIT();
+		EXIT(1);
 	}
 	if (pTable->count++ > (pTable->length) * 8 / 10) {
 		reallocht(pTable);
