@@ -9,8 +9,8 @@ extern char *malloc(), *realloc();
 /*			version 1.1: 	by Mokhtar Hirech (Jan. 92)	*/
 /*----------------------------------------------------------------------*/
 
-#include "mut306.h"
-#include "mlo400.h"
+#include MUT_H 
+#include MLO_H 
 
 /* ----	Defines          -----------------------------------------------*/
 
