@@ -2,8 +2,8 @@
 typedef union 	{
 	long	lval;
 	char	sval[100];
-	} YYSTYPE;
-extern YYSTYPE yylval;
+	} EDIFLSTYPE;
+extern EDIFLSTYPE edifllval;
 # define T_EDIF 257
 # define T_EDIFVERSION 258
 # define T_EDIFLEVEL 259
