@@ -1188,7 +1188,7 @@ lofig_list *ptfig;
 			{
 		num = atoi(str + 4);
 		str = spi_getdicname(num,ptdic);
-		if(str) (char *)ptaux_losig->NAMECHAIN->DATA = (char *)str;
+		if(str) ptaux_losig->NAMECHAIN->DATA = (void *)str;
 			}
 		else
 			{
