@@ -67,7 +67,7 @@ char *name, *string;
 	else
 		(void)fprintf(stderr, "\nvtiloadlofig : parsing file %s.%s\n",
 						name, IN_LO);
-	EXIT();
+	EXIT(1);
 }
 
 /*******************************************************************************
@@ -379,7 +379,7 @@ static char tn, tp;
 							for (c2 = c1->NEXT; c2; c2 = c2->NEXT)
 								if (c1->SIG == c2->SIG)
 									c2->NAME = NULL; /* to be deleted */
-						for (delete = &(locon_list *)ptcon->USER; *delete != NULL;)
+						for (delete = &ptcon->USER; *delete != NULL;)
 							if ((*delete)->NAME == NULL) {
 								c1 = (*delete)->NEXT;
 								mbkfree(*delete);
