@@ -1,3 +1,4 @@
+extern char *malloc(), *realloc();
 
 # line 12 "pat_prspat.yac"
 #include <stdio.h>
@@ -40,7 +41,7 @@ typedef union
   char          immd;
   char         *text;
   struct array  arra;
-  } pat_YYSTYPE;
+  } PAT_YYSTYPE;
 # define _IN 257
 # define _INOUT 258
 # define _LESym 259
@@ -70,12 +71,12 @@ typedef union
 #define pat_yyclearin pat_yychar = -1
 #define pat_yyerrok pat_yyerrflag = 0
 extern int pat_yychar;
-extern short pat_yyerrflag;
-#ifndef pat_YYMAXDEPTH
-#define pat_YYMAXDEPTH 150
+extern int pat_yyerrflag;
+#ifndef PAT_YYMAXDEPTH
+#define PAT_YYMAXDEPTH 150
 #endif
-pat_YYSTYPE pat_yylval, pat_yyval;
-# define pat_YYERRCODE 256
+PAT_YYSTYPE pat_yylval, pat_yyval;
+# define PAT_YYERRCODE 256
 
 # line 615 "pat_prspat.yac"
 
@@ -912,236 +913,635 @@ int  status;				/* (0,1,2) (bit,array,inside)	*/
       break;
     }
   }
-short pat_yyexca[] ={
+int pat_yyexca[] ={
 -1, 1,
 	0, -1,
 	-2, 0,
+-1, 4,
+	263, 4,
+	-2, 0,
 -1, 48,
 	265, 54,
 	-2, 33,
+-1, 62,
+	270, 10,
+	278, 10,
+	-2, 0,
 	};
-# define pat_YYNPROD 59
-# define pat_YYLAST 131
-short pat_yyact[]={
+# define PAT_YYNPROD 59
+# define PAT_YYLAST 131
+int pat_yyact[]={
 
-   8,  15,  17,  79,  16,  58,  28,  61,  28,  83,
-  79,  12,  87,  68,  55,  37,  24,  45,  57,  39,
-  19,  32,  24,  18,  67,  70,  49,  59,  12,  73,
-  24,  36,  40,  48,  49,  38,  25,  54,  71,  39,
-  31,  51,  50,  77,  14,   7,  42,  35,  47,  46,
-  27,  23,   5,  76,  65,  33,  56,  26,  29,  52,
-  10,   9,  11,  43,  62,  30,   6,   4,  72,  60,
-  41,  34,   3,   2,   1,  78,  13,  22,  21,  20,
-  44,   0,  53,   0,   0,   0,   0,  63,   0,   0,
-   0,   0,  66,   0,   0,  64,   0,   0,   0,   0,
-   0,   0,   0,  74,  69,   0,   0,   0,  44,  75,
-   0,  82,   0,  81,  84,  80,   0,   0,  85,   0,
-  86,   0,   0,  88,   0,   0,   0,   0,   0,   0,
-  66 };
-short pat_yypact[]={
+     8,    15,    17,    79,    16,    58,    28,    61,    28,    83,
+    79,    12,    87,    68,    55,    37,    24,    45,    57,    39,
+    19,    32,    24,    18,    67,    70,    49,    59,    12,    73,
+    24,    36,    40,    48,    49,    38,    25,    54,    71,    39,
+    31,    51,    50,    77,    14,     7,    42,    35,    47,    46,
+    27,    23,     5,    76,    65,    33,    56,    26,    29,    52,
+    10,     9,    11,    43,    62,    30,     6,     4,    72,    60,
+    41,    34,     3,     2,     1,    78,    13,    22,    21,    20,
+    44,     0,    53,     0,     0,     0,     0,    63,     0,     0,
+     0,     0,    66,     0,     0,    64,     0,     0,     0,     0,
+     0,     0,     0,    74,    69,     0,     0,     0,    44,    75,
+     0,    82,     0,    81,    84,    80,     0,     0,    85,     0,
+    86,     0,     0,    88,     0,     0,     0,     0,     0,     0,
+    66 };
+int pat_yypact[]={
 
--1000,-1000,-256,-227,-256,-1000,-1000,-1000,-274,-1000,
--1000,-1000,-1000,-250,-219,-1000,-1000,-1000,-1000,-1000,
--1000,-1000,-1000,-252,-1000,-1000,-1000,-1000,-1000,-240,
--258,-229,-222,-237,-239,-274,-1000,-242,-225,-263,
--245,-271,-1000,-1000,-1000,-274,-231,-1000,-1000,-1000,
--274,-1000,-253,-1000,-247,-1000,-223,-1000,-1000,-1000,
--241,-274,-239,-1000,-1000,-265,-1000,-240,-250,-274,
--1000,-268,-274,-1000,-1000,-1000,-272,-1000,-262,-1000,
--274,-1000,-1000,-1000,-1000,-1000,-1000,-1000,-274 };
-short pat_yypgo[]={
+ -1000, -1000,  -256,  -227,  -256, -1000, -1000, -1000,  -274, -1000,
+ -1000, -1000, -1000,  -250,  -219, -1000, -1000, -1000, -1000, -1000,
+ -1000, -1000, -1000,  -252, -1000, -1000, -1000, -1000, -1000,  -240,
+  -258,  -229,  -222,  -237,  -239,  -274, -1000,  -242,  -225,  -263,
+  -245,  -271, -1000, -1000, -1000,  -274,  -231, -1000, -1000, -1000,
+  -274, -1000,  -253, -1000,  -247, -1000,  -223, -1000, -1000, -1000,
+  -241,  -274,  -239, -1000, -1000,  -265, -1000,  -240,  -250,  -274,
+ -1000,  -268,  -274, -1000, -1000, -1000,  -272, -1000,  -262, -1000,
+  -274, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  -274 };
+int pat_yypgo[]={
 
-   0,  44,  79,  78,  77,  42,  47,  76,  49,  75,
-  51,  74,  73,  72,  71,  70,  69,  68,  41,  67,
-  52,  66,  45,  46,  64,  63,  62,  61,  60,  59,
-  56,  55,  48,  54,  53,  43 };
-short pat_yyr1[]={
+     0,    44,    79,    78,    77,    42,    47,    76,    49,    75,
+    51,    74,    73,    72,    71,    70,    69,    68,    41,    67,
+    52,    66,    45,    46,    64,    63,    62,    61,    60,    59,
+    56,    55,    48,    54,    53,    43 };
+int pat_yyr1[]={
 
-   0,  12,  14,  11,  13,  19,  19,  20,  20,  20,
-  15,  24,  24,  23,  23,  23,  22,  22,  21,  21,
-  27,  28,   6,   6,  29,  29,   1,   1,   1,   2,
-   3,   4,  10,  31,  31,  30,  30,   7,   7,   7,
-   7,   7,  26,  16,  16,  25,  25,  33,  32,  34,
-  34,  35,   9,   9,   8,  17,   5,   5,  18 };
-short pat_yyr2[]={
+     0,    12,    14,    11,    13,    19,    19,    20,    20,    20,
+    15,    24,    24,    23,    23,    23,    22,    22,    21,    21,
+    27,    28,     6,     6,    29,    29,     1,     1,     1,     2,
+     3,     4,    10,    31,    31,    30,    30,     7,     7,     7,
+     7,     7,    26,    16,    16,    25,    25,    33,    32,    34,
+    34,    35,     9,     9,     8,    17,     5,     5,    18 };
+int pat_yyr2[]={
 
-   0,   0,   0,   8,   1,   1,   2,   1,   1,   2,
-   2,   0,   2,   1,   1,   2,   1,   1,   1,   1,
-   4,   7,   0,   1,   1,   3,   1,   1,   1,   1,
-   4,   6,   2,   0,   3,   1,   1,   1,   1,   1,
-   1,   1,   6,   0,   2,   2,   1,   0,   4,   1,
-   2,   2,   0,   1,   1,   1,   1,   2,   1 };
-short pat_yychk[]={
+     0,     1,     1,    17,     2,     2,     4,     2,     2,     4,
+     4,     0,     4,     2,     2,     4,     2,     3,     2,     2,
+     9,    15,     1,     3,     3,     7,     3,     3,     3,     3,
+     9,    13,     5,     0,     7,     2,     2,     3,     3,     3,
+     3,     3,    13,     0,     5,     5,     2,     1,     9,     2,
+     4,     5,     1,     3,     3,     3,     3,     5,     3 };
+int pat_yychk[]={
 
--1000, -11, -12, -13, -19, -20, -21, -22, 256, -27,
- -28, -26, 267,  -7,  -1, 257, 260, 258, 279, 276,
-  -2,  -3,  -4, -10, 272, 263, -20, -18, 280,  -1,
- -10, 259, 273, -31, -14,  -6, 271, 273, 264, 261,
- 269, -15, -23, -25, -22, 256,  -8, -32, 272, 265,
-  -5, -18, -29,  -1, 262, 277, -30, 281, 268, 272,
- -16, 278, -24, -18, -32, -33, -18, 277, 266,  -8,
- 272, 261, -17, 270, -18, -23, -34, -35,  -9, 275,
-  -6,  -1, -18, 277, -18, -18, -35, 274,  -5 };
-short pat_yydef[]={
+ -1000,   -11,   -12,   -13,   -19,   -20,   -21,   -22,   256,   -27,
+   -28,   -26,   267,    -7,    -1,   257,   260,   258,   279,   276,
+    -2,    -3,    -4,   -10,   272,   263,   -20,   -18,   280,    -1,
+   -10,   259,   273,   -31,   -14,    -6,   271,   273,   264,   261,
+   269,   -15,   -23,   -25,   -22,   256,    -8,   -32,   272,   265,
+    -5,   -18,   -29,    -1,   262,   277,   -30,   281,   268,   272,
+   -16,   278,   -24,   -18,   -32,   -33,   -18,   277,   266,    -8,
+   272,   261,   -17,   270,   -18,   -23,   -34,   -35,    -9,   275,
+    -6,    -1,   -18,   277,   -18,   -18,   -35,   274,    -5 };
+int pat_yydef[]={
 
-   1,  -2,   0,   0,   4,   5,   7,   8,   0,  18,
-  19,  16,  17,   0,   0,  37,  38,  39,  40,  41,
-  26,  27,  28,  29,  33,   2,   6,   9,  58,  22,
-  29,   0,   0,  32,   0,   0,  23,   0,   0,   0,
-   0,  43,  11,  13,  14,   0,   0,  46,  -2,  47,
-  20,  56,   0,  24,   0,  30,   0,  35,  36,  34,
-   0,   0,  10,  15,  45,  52,  57,  22,   0,   0,
-  54,   0,   0,  55,  44,  12,  52,  49,   0,  53,
-   0,  25,  42,  31,   3,  48,  50,  51,  21 };
-#ifndef lint
-static char yaccpar_sccsid[] = "@(#)yaccpar	4.1	(Berkeley)	2/11/83";
-#endif not lint
-
-#
-# define pat_YYFLAG -1000
-# define pat_YYERROR goto pat_yyerrlab
-# define pat_YYACCEPT return(0)
-# define pat_YYABORT return(1)
-
-/*	parser for yacc output	*/
-
-#ifdef pat_YYDEBUG
-int pat_yydebug = 0; /* 1 for debugging */
+     1,    -2,     0,     0,    -2,     5,     7,     8,     0,    18,
+    19,    16,    17,     0,     0,    37,    38,    39,    40,    41,
+    26,    27,    28,    29,    33,     2,     6,     9,    58,    22,
+    29,     0,     0,    32,     0,     0,    23,     0,     0,     0,
+     0,    43,    11,    13,    14,     0,     0,    46,    -2,    47,
+    20,    56,     0,    24,     0,    30,     0,    35,    36,    34,
+     0,     0,    -2,    15,    45,    52,    57,    22,     0,     0,
+    54,     0,     0,    55,    44,    12,    52,    49,     0,    53,
+     0,    25,    42,    31,     3,    48,    50,    51,    21 };
+typedef struct { char *t_name; int t_val; } pat_yytoktype;
+#ifndef PAT_YYDEBUG
+#	define PAT_YYDEBUG	0	/* don't allow debugging */
 #endif
-pat_YYSTYPE pat_yyv[pat_YYMAXDEPTH]; /* where the values are stored */
-int pat_yychar = -1; /* current input token number */
-int pat_yynerrs = 0;  /* number of errors */
-short pat_yyerrflag = 0;  /* error recovery flag */
 
-pat_yyparse() {
+#if PAT_YYDEBUG
 
-	short pat_yys[pat_YYMAXDEPTH];
-	short pat_yyj, pat_yym;
-	register pat_YYSTYPE *pat_yypvt;
-	register short pat_yystate, *pat_yyps, pat_yyn;
-	register pat_YYSTYPE *pat_yypv;
-	register short *pat_yyxi;
+pat_yytoktype pat_yytoks[] =
+{
+	"_IN",	257,
+	"_INOUT",	258,
+	"_LESym",	259,
+	"_OUT",	260,
+	"AbstractLit",	261,
+	"BEFORE",	262,
+	"BEGIN_",	263,
+	"BitStringLit",	264,
+	"Colon",	265,
+	"Comma",	266,
+	"Comment",	267,
+	"DOWNTO",	268,
+	"Dot",	269,
+	"END_",	270,
+	"Format",	271,
+	"Identifier",	272,
+	"LeftParen",	273,
+	"Literal",	274,
+	"QuestionMark",	275,
+	"REGISTER",	276,
+	"RightParen",	277,
+	"SAVE",	278,
+	"SIGNAL",	279,
+	"Semicolon",	280,
+	"TO",	281,
+	"UnknownChar",	282,
+	"-unknown-",	-1	/* ends search */
+};
 
+char * pat_yyreds[] =
+{
+	"-no such reduction-",
+	"pat_format_file : /* empty */",
+	"pat_format_file : declarative_block BEGIN_",
+	"pat_format_file : declarative_block BEGIN_ description_block .save_statement. END_ERR Semicolon_ERR",
+	"declarative_block : ..declaration_item..",
+	"..declaration_item.. : declaration_item",
+	"..declaration_item.. : ..declaration_item.. declaration_item",
+	"declaration_item : input_output_declaration",
+	"declaration_item : other_statement",
+	"declaration_item : error Semicolon_ERR",
+	"description_block : description_item ..description_item..",
+	"..description_item.. : /* empty */",
+	"..description_item.. : ..description_item.. description_item",
+	"description_item : pattern_description",
+	"description_item : other_statement",
+	"description_item : error Semicolon_ERR",
+	"other_statement : initialization_statement",
+	"other_statement : Comment",
+	"input_output_declaration : signal_declaration",
+	"input_output_declaration : group_declaration",
+	"signal_declaration : mode name .Format. Semicolon..Semicolon..",
+	"group_declaration : mode Identifier...Identifier.. LeftParen ...name.. RightParen .Format. Semicolon..Semicolon..",
+	".Format. : /* empty */",
+	".Format. : Format",
+	"...name.. : name",
+	"...name.. : ...name.. Comma name",
+	"name : simple_name",
+	"name : indexed_name",
+	"name : slice_name",
+	"simple_name : Identifier...Identifier..",
+	"indexed_name : Identifier...Identifier.. LeftParen AbstractLit RightParen",
+	"slice_name : Identifier...Identifier.. LeftParen AbstractLit direction AbstractLit RightParen",
+	"Identifier...Identifier.. : Identifier ...Identifier..",
+	"...Identifier.. : /* empty */",
+	"...Identifier.. : ...Identifier.. Dot Identifier",
+	"direction : TO",
+	"direction : DOWNTO",
+	"mode : _IN",
+	"mode : _OUT",
+	"mode : _INOUT",
+	"mode : SIGNAL",
+	"mode : REGISTER",
+	"initialization_statement : name _LESym BitStringLit BEFORE label Semicolon_ERR",
+	".save_statement. : /* empty */",
+	".save_statement. : SAVE Semicolon_ERR",
+	"pattern_description : label unlabeled_pattern",
+	"pattern_description : unlabeled_pattern",
+	"unlabeled_pattern : Colon",
+	"unlabeled_pattern : Colon ..input_output_value.. Semicolon_ERR",
+	"..input_output_value.. : input_output_value",
+	"..input_output_value.. : ..input_output_value.. input_output_value",
+	"input_output_value : .QuestionMark. Literal",
+	".QuestionMark. : /* empty */",
+	".QuestionMark. : QuestionMark",
+	"label : Identifier",
+	"END_ERR : END_",
+	"Semicolon..Semicolon.. : Semicolon_ERR",
+	"Semicolon..Semicolon.. : Semicolon..Semicolon.. Semicolon_ERR",
+	"Semicolon_ERR : Semicolon",
+};
+#endif /* PAT_YYDEBUG */
+#line 1 "/usr/lib/yaccpar"
+/*	@(#)yaccpar 1.10 89/04/04 SMI; from S5R3 1.10	*/
+
+/*
+** Skeleton parser driver for yacc output
+*/
+
+/*
+** yacc user known macros and defines
+*/
+#define PAT_YYERROR		goto pat_yyerrlab
+#define PAT_YYACCEPT	{ free(pat_yys); free(pat_yyv); return(0); }
+#define PAT_YYABORT		{ free(pat_yys); free(pat_yyv); return(1); }
+#define PAT_YYBACKUP( newtoken, newvalue )\
+{\
+	if ( pat_yychar >= 0 || ( pat_yyr2[ pat_yytmp ] >> 1 ) != 1 )\
+	{\
+		pat_yyerror( "syntax error - cannot backup" );\
+		goto pat_yyerrlab;\
+	}\
+	pat_yychar = newtoken;\
+	pat_yystate = *pat_yyps;\
+	pat_yylval = newvalue;\
+	goto pat_yynewstate;\
+}
+#define PAT_YYRECOVERING()	(!!pat_yyerrflag)
+#ifndef PAT_YYDEBUG
+#	define PAT_YYDEBUG	1	/* make debugging available */
+#endif
+
+/*
+** user known globals
+*/
+int pat_yydebug;			/* set to 1 to get debugging */
+
+/*
+** driver internal defines
+*/
+#define PAT_YYFLAG		(-1000)
+
+/*
+** static variables used by the parser
+*/
+static PAT_YYSTYPE *pat_yyv;			/* value stack */
+static int *pat_yys;			/* state stack */
+
+static PAT_YYSTYPE *pat_yypv;			/* top of value stack */
+static int *pat_yyps;			/* top of state stack */
+
+static int pat_yystate;			/* current state */
+static int pat_yytmp;			/* extra var (lasts between blocks) */
+
+int pat_yynerrs;			/* number of errors */
+
+int pat_yyerrflag;			/* error recovery flag */
+int pat_yychar;			/* current input token number */
+
+
+/*
+** pat_yyparse - return 0 if worked, 1 if syntax error not recovered from
+*/
+int
+pat_yyparse()
+{
+	register PAT_YYSTYPE *pat_yypvt;	/* top of value stack for $vars */
+	unsigned pat_yymaxdepth = PAT_YYMAXDEPTH;
+
+	/*
+	** Initialize externals - pat_yyparse may be called more than once
+	*/
+	pat_yyv = (PAT_YYSTYPE*)malloc(pat_yymaxdepth*sizeof(PAT_YYSTYPE));
+	pat_yys = (int*)malloc(pat_yymaxdepth*sizeof(int));
+	if (!pat_yyv || !pat_yys)
+	{
+		pat_yyerror( "out of memory" );
+		return(1);
+	}
+	pat_yypv = &pat_yyv[-1];
+	pat_yyps = &pat_yys[-1];
 	pat_yystate = 0;
-	pat_yychar = -1;
+	pat_yytmp = 0;
 	pat_yynerrs = 0;
 	pat_yyerrflag = 0;
-	pat_yyps= &pat_yys[-1];
-	pat_yypv= &pat_yyv[-1];
+	pat_yychar = -1;
 
- pat_yystack:    /* put a state and value onto the stack */
+	goto pat_yystack;
+	{
+		register PAT_YYSTYPE *pat_yy_pv;	/* top of value stack */
+		register int *pat_yy_ps;		/* top of state stack */
+		register int pat_yy_state;		/* current state */
+		register int  pat_yy_n;		/* internal state number info */
 
-#ifdef pat_YYDEBUG
-	if( pat_yydebug  ) printf( "state %d, char 0%o\n", pat_yystate, pat_yychar );
-#endif
-		if( ++pat_yyps> &pat_yys[pat_YYMAXDEPTH] ) { pat_yyerror( "yacc stack overflow" ); return(1); }
-		*pat_yyps = pat_yystate;
-		++pat_yypv;
-		*pat_yypv = pat_yyval;
+		/*
+		** get globals into registers.
+		** branch to here only if PAT_YYBACKUP was called.
+		*/
+	pat_yynewstate:
+		pat_yy_pv = pat_yypv;
+		pat_yy_ps = pat_yyps;
+		pat_yy_state = pat_yystate;
+		goto pat_yy_newstate;
 
- pat_yynewstate:
+		/*
+		** get globals into registers.
+		** either we just started, or we just finished a reduction
+		*/
+	pat_yystack:
+		pat_yy_pv = pat_yypv;
+		pat_yy_ps = pat_yyps;
+		pat_yy_state = pat_yystate;
 
-	pat_yyn = pat_yypact[pat_yystate];
+		/*
+		** top of for (;;) loop while no reductions done
+		*/
+	pat_yy_stack:
+		/*
+		** put a state and value onto the stacks
+		*/
+#if PAT_YYDEBUG
+		/*
+		** if debugging, look up token value in list of value vs.
+		** name pairs.  0 and negative (-1) are special values.
+		** Note: linear search is used since time is not a real
+		** consideration while debugging.
+		*/
+		if ( pat_yydebug )
+		{
+			register int pat_yy_i;
 
-	if( pat_yyn<= pat_YYFLAG ) goto pat_yydefault; /* simple state */
-
-	if( pat_yychar<0 ) if( (pat_yychar=pat_yylex())<0 ) pat_yychar=0;
-	if( (pat_yyn += pat_yychar)<0 || pat_yyn >= pat_YYLAST ) goto pat_yydefault;
-
-	if( pat_yychk[ pat_yyn=pat_yyact[ pat_yyn ] ] == pat_yychar ){ /* valid shift */
-		pat_yychar = -1;
-		pat_yyval = pat_yylval;
-		pat_yystate = pat_yyn;
-		if( pat_yyerrflag > 0 ) --pat_yyerrflag;
-		goto pat_yystack;
-		}
-
- pat_yydefault:
-	/* default state action */
-
-	if( (pat_yyn=pat_yydef[pat_yystate]) == -2 ) {
-		if( pat_yychar<0 ) if( (pat_yychar=pat_yylex())<0 ) pat_yychar = 0;
-		/* look through exception table */
-
-		for( pat_yyxi=pat_yyexca; (*pat_yyxi!= (-1)) || (pat_yyxi[1]!=pat_yystate) ; pat_yyxi += 2 ) ; /* VOID */
-
-		while( *(pat_yyxi+=2) >= 0 ){
-			if( *pat_yyxi == pat_yychar ) break;
+			(void)printf( "State %d, token ", pat_yy_state );
+			if ( pat_yychar == 0 )
+				(void)printf( "end-of-file\n" );
+			else if ( pat_yychar < 0 )
+				(void)printf( "-none-\n" );
+			else
+			{
+				for ( pat_yy_i = 0; pat_yytoks[pat_yy_i].t_val >= 0;
+					pat_yy_i++ )
+				{
+					if ( pat_yytoks[pat_yy_i].t_val == pat_yychar )
+						break;
+				}
+				(void)printf( "%s\n", pat_yytoks[pat_yy_i].t_name );
 			}
-		if( (pat_yyn = pat_yyxi[1]) < 0 ) return(0);   /* accept */
 		}
+#endif /* PAT_YYDEBUG */
+		if ( ++pat_yy_ps >= &pat_yys[ pat_yymaxdepth ] )	/* room on stack? */
+		{
+			/*
+			** reallocate and recover.  Note that pointers
+			** have to be reset, or bad things will happen
+			*/
+			int pat_yyps_index = (pat_yy_ps - pat_yys);
+			int pat_yypv_index = (pat_yy_pv - pat_yyv);
+			int pat_yypvt_index = (pat_yypvt - pat_yyv);
+			pat_yymaxdepth += PAT_YYMAXDEPTH;
+			pat_yyv = (PAT_YYSTYPE*)realloc((char*)pat_yyv,
+				pat_yymaxdepth * sizeof(PAT_YYSTYPE));
+			pat_yys = (int*)realloc((char*)pat_yys,
+				pat_yymaxdepth * sizeof(int));
+			if (!pat_yyv || !pat_yys)
+			{
+				pat_yyerror( "yacc stack overflow" );
+				return(1);
+			}
+			pat_yy_ps = pat_yys + pat_yyps_index;
+			pat_yy_pv = pat_yyv + pat_yypv_index;
+			pat_yypvt = pat_yyv + pat_yypvt_index;
+		}
+		*pat_yy_ps = pat_yy_state;
+		*++pat_yy_pv = pat_yyval;
 
-	if( pat_yyn == 0 ){ /* error */
-		/* error ... attempt to resume parsing */
-
-		switch( pat_yyerrflag ){
-
-		case 0:   /* brand new error */
-
-			pat_yyerror( "syntax error" );
-		pat_yyerrlab:
-			++pat_yynerrs;
-
-		case 1:
-		case 2: /* incompletely recovered error ... try again */
-
-			pat_yyerrflag = 3;
-
-			/* find a state where "error" is a legal shift action */
-
-			while ( pat_yyps >= pat_yys ) {
-			   pat_yyn = pat_yypact[*pat_yyps] + pat_YYERRCODE;
-			   if( pat_yyn>= 0 && pat_yyn < pat_YYLAST && pat_yychk[pat_yyact[pat_yyn]] == pat_YYERRCODE ){
-			      pat_yystate = pat_yyact[pat_yyn];  /* simulate a shift of "error" */
-			      goto pat_yystack;
-			      }
-			   pat_yyn = pat_yypact[*pat_yyps];
-
-			   /* the current pat_yyps has no shift onn "error", pop stack */
-
-#ifdef pat_YYDEBUG
-			   if( pat_yydebug ) printf( "error recovery pops state %d, uncovers %d\n", *pat_yyps, pat_yyps[-1] );
+		/*
+		** we have a new state - find out what to do
+		*/
+	pat_yy_newstate:
+		if ( ( pat_yy_n = pat_yypact[ pat_yy_state ] ) <= PAT_YYFLAG )
+			goto pat_yydefault;		/* simple state */
+#if PAT_YYDEBUG
+		/*
+		** if debugging, need to mark whether new token grabbed
+		*/
+		pat_yytmp = pat_yychar < 0;
 #endif
-			   --pat_yyps;
-			   --pat_yypv;
-			   }
+		if ( ( pat_yychar < 0 ) && ( ( pat_yychar = pat_yylex() ) < 0 ) )
+			pat_yychar = 0;		/* reached EOF */
+#if PAT_YYDEBUG
+		if ( pat_yydebug && pat_yytmp )
+		{
+			register int pat_yy_i;
 
-			/* there is no state on the stack with an error shift ... abort */
-
-	pat_yyabort:
-			return(1);
-
-
-		case 3:  /* no shift yet; clobber input char */
-
-#ifdef pat_YYDEBUG
-			if( pat_yydebug ) printf( "error recovery discards char %d\n", pat_yychar );
-#endif
-
-			if( pat_yychar == 0 ) goto pat_yyabort; /* don't discard EOF, quit */
+			(void)printf( "Received token " );
+			if ( pat_yychar == 0 )
+				(void)printf( "end-of-file\n" );
+			else if ( pat_yychar < 0 )
+				(void)printf( "-none-\n" );
+			else
+			{
+				for ( pat_yy_i = 0; pat_yytoks[pat_yy_i].t_val >= 0;
+					pat_yy_i++ )
+				{
+					if ( pat_yytoks[pat_yy_i].t_val == pat_yychar )
+						break;
+				}
+				(void)printf( "%s\n", pat_yytoks[pat_yy_i].t_name );
+			}
+		}
+#endif /* PAT_YYDEBUG */
+		if ( ( ( pat_yy_n += pat_yychar ) < 0 ) || ( pat_yy_n >= PAT_YYLAST ) )
+			goto pat_yydefault;
+		if ( pat_yychk[ pat_yy_n = pat_yyact[ pat_yy_n ] ] == pat_yychar )	/*valid shift*/
+		{
 			pat_yychar = -1;
-			goto pat_yynewstate;   /* try again in the same state */
-
-			}
-
+			pat_yyval = pat_yylval;
+			pat_yy_state = pat_yy_n;
+			if ( pat_yyerrflag > 0 )
+				pat_yyerrflag--;
+			goto pat_yy_stack;
 		}
 
-	/* reduction by production pat_yyn */
-
-#ifdef pat_YYDEBUG
-		if( pat_yydebug ) printf("reduce %d\n",pat_yyn);
+	pat_yydefault:
+		if ( ( pat_yy_n = pat_yydef[ pat_yy_state ] ) == -2 )
+		{
+#if PAT_YYDEBUG
+			pat_yytmp = pat_yychar < 0;
 #endif
-		pat_yyps -= pat_yyr2[pat_yyn];
-		pat_yypvt = pat_yypv;
-		pat_yypv -= pat_yyr2[pat_yyn];
-		pat_yyval = pat_yypv[1];
-		pat_yym=pat_yyn;
-			/* consult goto table to find next state */
-		pat_yyn = pat_yyr1[pat_yyn];
-		pat_yyj = pat_yypgo[pat_yyn] + *pat_yyps + 1;
-		if( pat_yyj>=pat_YYLAST || pat_yychk[ pat_yystate = pat_yyact[pat_yyj] ] != -pat_yyn ) pat_yystate = pat_yyact[pat_yypgo[pat_yyn]];
-		switch(pat_yym){
-			
+			if ( ( pat_yychar < 0 ) && ( ( pat_yychar = pat_yylex() ) < 0 ) )
+				pat_yychar = 0;		/* reached EOF */
+#if PAT_YYDEBUG
+			if ( pat_yydebug && pat_yytmp )
+			{
+				register int pat_yy_i;
+
+				(void)printf( "Received token " );
+				if ( pat_yychar == 0 )
+					(void)printf( "end-of-file\n" );
+				else if ( pat_yychar < 0 )
+					(void)printf( "-none-\n" );
+				else
+				{
+					for ( pat_yy_i = 0;
+						pat_yytoks[pat_yy_i].t_val >= 0;
+						pat_yy_i++ )
+					{
+						if ( pat_yytoks[pat_yy_i].t_val
+							== pat_yychar )
+						{
+							break;
+						}
+					}
+					(void)printf( "%s\n", pat_yytoks[pat_yy_i].t_name );
+				}
+			}
+#endif /* PAT_YYDEBUG */
+			/*
+			** look through exception table
+			*/
+			{
+				register int *pat_yyxi = pat_yyexca;
+
+				while ( ( *pat_yyxi != -1 ) ||
+					( pat_yyxi[1] != pat_yy_state ) )
+				{
+					pat_yyxi += 2;
+				}
+				while ( ( *(pat_yyxi += 2) >= 0 ) &&
+					( *pat_yyxi != pat_yychar ) )
+					;
+				if ( ( pat_yy_n = pat_yyxi[1] ) < 0 )
+					PAT_YYACCEPT;
+			}
+		}
+
+		/*
+		** check for syntax error
+		*/
+		if ( pat_yy_n == 0 )	/* have an error */
+		{
+			/* no worry about speed here! */
+			switch ( pat_yyerrflag )
+			{
+			case 0:		/* new error */
+				pat_yyerror( "syntax error" );
+				goto skip_init;
+			pat_yyerrlab:
+				/*
+				** get globals into registers.
+				** we have a user generated syntax type error
+				*/
+				pat_yy_pv = pat_yypv;
+				pat_yy_ps = pat_yyps;
+				pat_yy_state = pat_yystate;
+				pat_yynerrs++;
+			skip_init:
+			case 1:
+			case 2:		/* incompletely recovered error */
+					/* try again... */
+				pat_yyerrflag = 3;
+				/*
+				** find state where "error" is a legal
+				** shift action
+				*/
+				while ( pat_yy_ps >= pat_yys )
+				{
+					pat_yy_n = pat_yypact[ *pat_yy_ps ] + PAT_YYERRCODE;
+					if ( pat_yy_n >= 0 && pat_yy_n < PAT_YYLAST &&
+						pat_yychk[pat_yyact[pat_yy_n]] == PAT_YYERRCODE)					{
+						/*
+						** simulate shift of "error"
+						*/
+						pat_yy_state = pat_yyact[ pat_yy_n ];
+						goto pat_yy_stack;
+					}
+					/*
+					** current state has no shift on
+					** "error", pop stack
+					*/
+#if PAT_YYDEBUG
+#	define _POP_ "Error recovery pops state %d, uncovers state %d\n"
+					if ( pat_yydebug )
+						(void)printf( _POP_, *pat_yy_ps,
+							pat_yy_ps[-1] );
+#	undef _POP_
+#endif
+					pat_yy_ps--;
+					pat_yy_pv--;
+				}
+				/*
+				** there is no state on stack with "error" as
+				** a valid shift.  give up.
+				*/
+				PAT_YYABORT;
+			case 3:		/* no shift yet; eat a token */
+#if PAT_YYDEBUG
+				/*
+				** if debugging, look up token in list of
+				** pairs.  0 and negative shouldn't occur,
+				** but since timing doesn't matter when
+				** debugging, it doesn't hurt to leave the
+				** tests here.
+				*/
+				if ( pat_yydebug )
+				{
+					register int pat_yy_i;
+
+					(void)printf( "Error recovery discards " );
+					if ( pat_yychar == 0 )
+						(void)printf( "token end-of-file\n" );
+					else if ( pat_yychar < 0 )
+						(void)printf( "token -none-\n" );
+					else
+					{
+						for ( pat_yy_i = 0;
+							pat_yytoks[pat_yy_i].t_val >= 0;
+							pat_yy_i++ )
+						{
+							if ( pat_yytoks[pat_yy_i].t_val
+								== pat_yychar )
+							{
+								break;
+							}
+						}
+						(void)printf( "token %s\n",
+							pat_yytoks[pat_yy_i].t_name );
+					}
+				}
+#endif /* PAT_YYDEBUG */
+				if ( pat_yychar == 0 )	/* reached EOF. quit */
+					PAT_YYABORT;
+				pat_yychar = -1;
+				goto pat_yy_newstate;
+			}
+		}/* end if ( pat_yy_n == 0 ) */
+		/*
+		** reduction by production pat_yy_n
+		** put stack tops, etc. so things right after switch
+		*/
+#if PAT_YYDEBUG
+		/*
+		** if debugging, print the string that is the user's
+		** specification of the reduction which is just about
+		** to be done.
+		*/
+		if ( pat_yydebug )
+			(void)printf( "Reduce by (%d) \"%s\"\n",
+				pat_yy_n, pat_yyreds[ pat_yy_n ] );
+#endif
+		pat_yytmp = pat_yy_n;			/* value to switch over */
+		pat_yypvt = pat_yy_pv;			/* $vars top of value stack */
+		/*
+		** Look in goto table for next state
+		** Sorry about using pat_yy_state here as temporary
+		** register variable, but why not, if it works...
+		** If pat_yyr2[ pat_yy_n ] doesn't have the low order bit
+		** set, then there is no action to be done for
+		** this reduction.  So, no saving & unsaving of
+		** registers done.  The only difference between the
+		** code just after the if and the body of the if is
+		** the goto pat_yy_stack in the body.  This way the test
+		** can be made before the choice of what to do is needed.
+		*/
+		{
+			/* length of production doubled with extra bit */
+			register int pat_yy_len = pat_yyr2[ pat_yy_n ];
+
+			if ( !( pat_yy_len & 01 ) )
+			{
+				pat_yy_len >>= 1;
+				pat_yyval = ( pat_yy_pv -= pat_yy_len )[1];	/* $$ = $1 */
+				pat_yy_state = pat_yypgo[ pat_yy_n = pat_yyr1[ pat_yy_n ] ] +
+					*( pat_yy_ps -= pat_yy_len ) + 1;
+				if ( pat_yy_state >= PAT_YYLAST ||
+					pat_yychk[ pat_yy_state =
+					pat_yyact[ pat_yy_state ] ] != -pat_yy_n )
+				{
+					pat_yy_state = pat_yyact[ pat_yypgo[ pat_yy_n ] ];
+				}
+				goto pat_yy_stack;
+			}
+			pat_yy_len >>= 1;
+			pat_yyval = ( pat_yy_pv -= pat_yy_len )[1];	/* $$ = $1 */
+			pat_yy_state = pat_yypgo[ pat_yy_n = pat_yyr1[ pat_yy_n ] ] +
+				*( pat_yy_ps -= pat_yy_len ) + 1;
+			if ( pat_yy_state >= PAT_YYLAST ||
+				pat_yychk[ pat_yy_state = pat_yyact[ pat_yy_state ] ] != -pat_yy_n )
+			{
+				pat_yy_state = pat_yyact[ pat_yypgo[ pat_yy_n ] ];
+			}
+		}
+					/* save until reenter driver code */
+		pat_yystate = pat_yy_state;
+		pat_yyps = pat_yy_ps;
+		pat_yypv = pat_yy_pv;
+	}
+	/*
+	** code supplied by user is placed in this switch
+	*/
+	switch( pat_yytmp )
+	{
+		
 case 1:
 # line 97 "pat_prspat.yac"
 {
@@ -1538,8 +1938,7 @@ case 57:
 		} break;
 case 58:
 # line 613 "pat_prspat.yac"
-{ pat_yyerrok; } break; 
-		}
-		goto pat_yystack;  /* stack new state and value */
-
+{ pat_yyerrok; } break;
 	}
+	goto pat_yystack;		/* reset registers in driver code */
+}
