@@ -16,6 +16,9 @@
 #include "sl_util.h"
 #include <sys/errno.h>
 #include <stdio.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 /*---------------------------------------------------------------------------
 existDirectory  : renvoie si le repertoire path existe ou non.
@@ -26,20 +29,11 @@ retour		: int
 int existDirectory(path)
 char *path;
 {
-FILE *fich;
-FILE *fopen();
+  struct stat buf;
 
-fich = fopen(path,"r");
-if (fich && (fich->_flag & EISDIR))
-   {
-   fclose(fich);
-   return(1);
-   }
-else
-   {
-   fclose(fich);
-   return(0);
-   }
+  if ((stat(path, &buf) == 0) && S_ISDIR(buf.st_mode))
+    return(1);
+  return(0);
 }
 
 /*---------------------------------------------------------------------------
@@ -1139,25 +1133,22 @@ while (name1[i] != '\0')
    i++;
    }
 name = namealloc(name1);
-#ifndef LEO
-   mbkfree((void *)name1);	/* chaine */
-#endif
 
 if (name[0] == 'a' && name[1] == 'u' && name[2] == 'x')
    {
    length = strlen(name);
+   mbkfree((void *) name1);
    name1 = (char *)  mbkalloc (length+3);
    
    strcpy(name1,name);
    name1[length] =  '_';
    name1[length+1]   =  'a';
    name1[length+2] = '\0';
+   retour = namealloc(name1);
    }
-   
-retour = namealloc(name1);
-#ifndef LEO
-   mbkfree((void *)name1);	/* chaine */
-#endif
+else
+   retour = name;
+mbkfree((void *) name1);	/* chaine */
 return(retour);
 }
 /*-------------------------------------------------------------------------
