@@ -6,7 +6,7 @@ extern void savecif();
 #ifdef DRIVECIF_C
 static char *busname();
 static void drive_model();
-static getcifmodel();
+static long getcifmodel();
 static void wr_con();
 static void wr_figure();
 static void wr_header();
