@@ -15,12 +15,12 @@
 static int errno;
 #endif
 #include "generic.h"
-#include "gds_type.h"
-#include "gds_code.h"
 #include MUT_H
 #include RDS_H
 #include RPR_H
 #include RUT_H
+#include "gds_type.h"
+#include "gds_code.h"
 #include "parse_gds.h"
 
 /* variables globales mais internes au fichier */
@@ -460,7 +460,17 @@ char *texte1, *texte2;
 *
 ***/
 
-#define traitebool(a) (a != 0) ? pv_set_pv_error(a) : (errno != 0) ? pv_set_pv_error(IOERR) : pv_set_pv_error(TRUNCERR)
+/* Doesn't work on dec system, why ?
+#define traitebool(a) ((a != 0) ? pv_set_pv_error(a) : (errno != 0) ? pv_set_pv_error(IOERR) : pv_set_pv_error(TRUNCERR))
+*/
+#define traitebool(a) do {                                   \
+			if (a != 0)                          \
+				pv_set_pv_error(a);          \
+			else if (errno != 0)                 \
+				pv_set_pv_error(IOERR);      \
+			else                                 \
+				pv_set_pv_error(TRUNCERR);   \
+		} while (0)
 
 
 /*********
