@@ -555,9 +555,33 @@ long		*Counter;
    ptScrCon->X = NewWidth;
 
 }
+/******************************************************************************/
+/* Function : Scr_GetSigName()          4 juin 1993                           */
+/*                                                                            */
+/* Description :                                                              */
+/*                                                                            */
+/*      Input parameters :                                                    */
+/*      Input global Variables :                                              */
+/*      Output parameters :                                                   */
+/*      Output global Variables :                                             */
+/*                                                                            */
+/******************************************************************************/
+char	*ScrGetSigName(ptSig, SigIndex)
+Signal	*ptSig;
+long	SigIndex;
+
+{
+ for (;ptSig; ptSig = ptSig->NEXT) {
+ if (ptSig->INDEX == SigIndex) {
+  return(ptSig->NAME);
+ }
+ /* si ptSig est NULL alors il ya un bug */
+ if (ptSig == NULL) return NULL;
+ }
+} 
 
 /******************************************************************************/
-/* Function :                                                                 */
+/* Function : Scr2Mbk                                                         */
 /*                                                                            */
 /* Description :                                                              */
 /*                                                                            */
@@ -615,6 +639,11 @@ long			VerticalChannelWidth;
  long           ChannelWidth = 0;
  long           ChannelHeight = 0;
  long           CellLineNumber = 0;
+/***** 4 juin 1993 ****/
+ char           *NameSeg;
+ char           Buffer[10];
+ long           IndexSignal = 0;
+/*********/
 
  NameVdd = namealloc("VDD");
  NameVss = namealloc("VSS");
@@ -648,9 +677,18 @@ long			VerticalChannelWidth;
      X2Segment = ((X2Symbolic - 1) * PITCH_X) + WESTOFFSET + Xab1;	
     Y1Segment = Y2Segment = (((CurrentSeg->Y1Seg - 1) * PITCH_Y) + SOUTHOFFSET)
                             + YLine;
+/************************************/
+/* Ajout du 4 juin 1993 pour retrouver les vrais noms des segments */
+/************************************/
+   strcpy(Buffer,CurrentSeg->SegName);
+   strtok(Buffer,TRICE);
+   IndexSignal = atol(strtok(NULL,TRICE));
+   if ((NameSeg = ScrGetSigName(ptfig->SIG, IndexSignal)) == NULL)
+    NameSeg = CurrentSeg->SegName;
+/************************************/
     ptMbkRoot->PHSEG = addphseg(ptMbkRoot, ((char )ALU1), LAYER1WIDTH, 
                                 X1Segment, Y1Segment, X2Segment , Y2Segment, 
-                                CurrentSeg->SegName); 
+                                NameSeg); 
    }
 
 /******************************************************************************/
@@ -668,9 +706,18 @@ long			VerticalChannelWidth;
      Y2Segment = ((Y2Symbolic - 1) * PITCH_Y) + SOUTHOFFSET + YLine;
     X1Segment = X2Segment = ((CurrentSeg->X1Seg - 1) * PITCH_X) + WESTOFFSET +
                             Xab1;
+/************************************/
+/* Ajout du 4 juin 1993 pour retrouver les vrais noms des segments */
+/************************************/
+   strcpy(Buffer,CurrentSeg->SegName);
+   strtok(Buffer,TRICE);
+   IndexSignal = atol(strtok(NULL,TRICE));
+   if ((NameSeg = ScrGetSigName(ptfig->SIG, IndexSignal)) == NULL)
+    NameSeg = CurrentSeg->SegName;
+/************************************/
     ptMbkRoot->PHSEG = addphseg(ptMbkRoot, ((char )ALU2), LAYER2WIDTH, 
                                 X1Segment, Y1Segment, X2Segment, Y2Segment, 
-                                CurrentSeg->SegName);
+                                NameSeg);
    }
 
 /******************************************************************************/
