@@ -43,7 +43,9 @@ char polarity;
   lofig_list *fig = getlofig(fName,'A');
   ptype_list *res;
   begen_list *beh_addbegen();
+/*
   ptype_list *pTLGen;
+*/
   int *pval;
 
   befig_list *bhCell;
@@ -86,13 +88,17 @@ char polarity;
   res = caracLofig(fName);
 
                /* ajout des generic(s) */
+  bhCell->BEGEN = NULL;
 
+/* --- Inutile depuis la nouvelle BEFIG (NAT le 26/03/93) 
   bhCell->USER = addptype(NULL,BEH_GENERIC,NULL);
   pTLGen = getptype(bhCell->USER,BEH_GENERIC);
-
   pTLGen->DATA = NULL;
+   --- par la suite tous les bhCell->DATA ont ete remplaces par bhCell->BEGEN
+*/
+
  
-/*  inutile par rapport au nouvel sclib
+/*  --- inutile par rapport au nouvel sclib
 
   pval = (int *) mbkalloc (sizeof(int));
   *pval = getCarac(res,"fanout");
@@ -103,7 +109,7 @@ char polarity;
 
   pval = (int *) mbkalloc (sizeof(int));
   *pval = area*252; 
-  pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,namealloc("area"),
+  bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,namealloc("area"),
                             namealloc("natural"),(void *)pval);
 
   in = bhCell->BERIN;
@@ -113,41 +119,41 @@ char polarity;
 
      pval = (int *) mbkalloc (sizeof(int));
      *pval = getCaracInput(res,"cin",name);
-     pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,genNAME("cin_%s",name),
+     bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,genNAME("cin_%s",name),
                                namealloc("natural"),(void *)pval);
 
      pval = (int *) mbkalloc (sizeof(int));
      *pval = getCaracInput(res,"rup",name);
-     pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,genNAME("rup_%s",name),
+     bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,genNAME("rup_%s",name),
                                namealloc("natural"),(void *)pval);
 
      pval = (int *) mbkalloc (sizeof(int));
      *pval = getCaracInput(res,"rdown",name);
-     pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,genNAME("rdown_%s",name),
+     bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,genNAME("rdown_%s",name),
                                namealloc("natural"),(void *)pval);
 
      if (getCarac(res,"type"))
         {
         pval = (int *) mbkalloc (sizeof(int));
         *pval = getCaracInput(res,"tphh",name);
-        pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,genNAME("tphh_%s",name),
+        bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,genNAME("tphh_%s",name),
                                   namealloc("natural"),(void *)pval);
 
         pval = (int *) mbkalloc (sizeof(int));
         *pval = getCaracInput(res,"tpll",name);
-        pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,genNAME("tpll_%s",name),
+        bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,genNAME("tpll_%s",name),
                                   namealloc("natural"),(void *)pval);
         }
      else
         {
         pval = (int *) mbkalloc (sizeof(int));
         *pval = getCaracInput(res,"tplh",name);
-        pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,genNAME("tplh_%s",name),
+        bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,genNAME("tplh_%s",name),
                                   namealloc("natural"),(void *)pval);
 
         pval = (int *) mbkalloc (sizeof(int));
         *pval = getCaracInput(res,"tphl",name);
-        pTLGen->DATA = (void *)beh_addbegen(pTLGen->DATA,genNAME("tphl_%s",name),
+        bhCell->BEGEN = (void *)beh_addbegen(bhCell->BEGEN,genNAME("tphl_%s",name),
                                   namealloc("natural"),(void *)pval);
         }
      in = in->NEXT;
