@@ -709,6 +709,18 @@ for(aux = interface;aux;aux = aux->NEXT)
 return (Alist *)reverse((chain_list *)tri);
 }
 
+/*************************************************************************/
+/* IDENT :	mirrorExpr						 */
+/* 		effectue un reverse a tous les niveaux de l'expression   */
+/* RETURN :	void (expression modifiee physiquement)			 */
+/*************************************************************************/
+void mirrorExpr(expr)
+chain_list *expr;
+{
+   expr->NEXT = (chain_list *)reverse(CDR(expr));
+   while (expr = CDR(expr)) mirrorExpr(CAR(expr));
+}
+
 /******************************************************************************/
 /***** normMappingExpr ***/
 /******************************************************************************/
@@ -717,6 +729,7 @@ chain_list *expr;
 {
 chain_list *e,*ep;
 
+   mirrorExpr(expr);
    e = copyExpr(expr);
    flatArityExpr(e);
    if (searchOperExpr(e,NOT))
